/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: BeanInfo.java 4049 2008-10-03 12:51:24Z eyindanga $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.container.info;

import static javax.ejb.TransactionManagementType.CONTAINER;

import java.util.Map;

import javax.ejb.ApplicationException;
import javax.ejb.TransactionManagementType;

import org.ow2.easybeans.api.bean.info.IBeanInfo;
import org.ow2.easybeans.api.bean.info.ISecurityInfo;

/**
 * This class contains description for a bean.
 * It is used at the runtime.
 * @author Florent Benoit
 */
public class BeanInfo implements IBeanInfo {

    /**
     * Bean's name.
     */
    private String name;

    /**
     * Security info.
     */
    private ISecurityInfo securityInfo = null;

    /**
     * Management type for the bean.
     */
    private TransactionManagementType transactionManagementType = CONTAINER;

    /**
     * List of application exceptions used on this ejb-jar.
     */
    private Map<String, ApplicationException> applicationExceptions = null;

    /**
     * Cluster configuration.
     */
    Object cluster;


    /**
     * Gets the list of application exceptions defined on this ejb jar metadata.
     * @return the list of application exceptions defined on this ejb jar metadata.
     */
    public Map<String, ApplicationException> getApplicationExceptions() {
        return this.applicationExceptions;
    }

    /**
     * Sets the list of application exceptions defined on this ejb jar metadata.
     * @param applicationExceptions the list of application exceptions defined on this ejb jar metadata.
     */
    public void setApplicationExceptions(final Map<String, ApplicationException> applicationExceptions) {
        this.applicationExceptions = applicationExceptions;
    }

    /**
     * Gets the type of transaction for the given bean.
     * @return transaction management type.
     */
    public TransactionManagementType getTransactionManagementType() {
        return this.transactionManagementType;
    }

    /**
     * Sets the type of transaction for the given bean.
     * @param transactionManagementType transaction management type.
     */
    public void setTransactionManagementType(final TransactionManagementType transactionManagementType) {
        this.transactionManagementType = transactionManagementType;
    }

    /**
     * Sets the security info.
     * @param securityInfo security info.
     */
    public void setSecurityInfo(final ISecurityInfo securityInfo) {
        this.securityInfo = securityInfo;
    }


    /**
     * Gets the security info.
     * @return security info.
     */
    public ISecurityInfo getSecurityInfo() {
        return this.securityInfo;
    }

    /**
     * Gets the name of the bean.
     * @return the name of the bean.
     */
    public String getName() {
        return this.name;
    }

    /**
     * Sets the name of the bean.
     * @param name the bean's name.
     */
    public void setName(final String name) {
        this.name = name;
    }

    /**
     * Gets configuration of the cluster, if the bean is clustered.
     * @return the cluster
     */
    public Object getCluster() {
        return this.cluster;
    }

    /**
     * Sets configuration of the cluster, if the bean is clustered.
     * @param cluster the cluster to set
     */
    public void setCluster(final Object cluster) {
        this.cluster = cluster;
    }
}
